@@ -18,7 +18,7 @@ ggplot(dat, aes(Group, Value)) +
   geom_signif(stat="identity",
               data=data.frame(x=c(0.875, 1.875), xend=c(1.125, 2.125),
                               y=c(5.8, 8.5), annotation=c("**", "NS")),
-              aes(x=x,xend=xend, y=y, yend=y, annotation=annotation)) +
+              aes(x=x,xend=xend, y=y, yend=y, annotation=annotation, group=c(1,2))) +
   geom_signif(comparisons=list(c("S1", "S2")), annotations="***",
               y_position = 9.3, tip_length = 0, vjust=0.4) +
   scale_fill_manual(values = c("grey80", "grey20"))
